#
# spec file for package pappl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pappl
%define lname   libpappl1
Version:        1.4.6
Release:        1.2
Summary:        A printer application framework
License:        Apache-2.0
Group:          Hardware/Printing
URL:            https://www.msweet.org/pappl/
Source:         https://github.com/michaelrsweet/pappl/releases/download/v%version/pappl-%version.tar.gz
Source2:        https://github.com/michaelrsweet/pappl/releases/download/v%version/pappl-%version.tar.gz.sig
Source3:        %name.keyring
BuildRequires:  cups-devel > 2.2.6
BuildRequires:  pam-devel
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(zlib)

%description
PAPPL is a C-based framework/library for developing CUPS Printer
Applications, which are the recommended replacement for printer
drivers. PAPPL supports LPrint and a Gutenprint Printer Application,
but it is sufficiently general purpose to support any kind of printer
or driver that can be used on desktops, servers and in embedded
environments.

PAPPL supports JPEG, PNG, PWG Raster, Apple Raster, and "raw"
printing to printers connected via USB and network
(AppSocket/JetDirect) connections. PAPPL provides access to the
printer via its embedded IPP Everywhere service, either local to the
computer or on your whole network, which can then be discovered and
used by any application.

%package -n %lname
Summary:        A printer application framework
Group:          System/Libraries

%description -n %lname
PAPPL is a framework/library for developing CUPS Printer
Applications, which are the recommended replacement for printer
drivers.

PAPPL supports JPEG, PNG, PWG Raster, Apple Raster, and "raw"
printing to printers connected via USB and network
(AppSocket/JetDirect) connections.

%package devel
Summary:        Development files for PAPPL
Group:          Development/Libraries/C and C++
Requires:       %lname = %version-%release

%description devel
PAPPL is a C-based framework/library for developing CUPS Printer
Applications, which are the recommended replacement for printer
drivers.

This subpackage contains the headers for the library.

%prep
%autosetup -p1

%build
perl -i -lpe 's{^\.SILENT:.*}{}g' Makedefs.in
# includedir intentional, cf. bugzilla.opensuse.org/795968
%configure --disable-static --includedir="%_includedir/%name"
%make_build

%install
# quite dumb to concatenate RPM_BUILD_ROOT and DESTDIR
%make_install RPM_BUILD_ROOT=""
rm -f "%buildroot/%_libdir"/*.a

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%_bindir/pappl-*
%_mandir/man1/*.1*
%_datadir/%name/
%license LICENSE

%files -n %lname
%_libdir/libpappl.so.1*

%files devel
%_includedir/%name/
%_libdir/libpappl.so
%_libdir/pkgconfig/*.pc
%_mandir/man3/pappl-*
%_datadir/doc/%name/

%changelog
* Sat Feb 10 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4.6
  * Fixed reporting of "printer-strings-languages-supported" attribute
  * Fixed saving of "print-darkness-default" and
    "print-speed-default" values
  * Fixed incoming "raw" print socket support
  * Fixed web interface support for "printer-darkness"
* Fri Jan 26 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4.5
  * Fixed support for "finishings", "output-bin", and "sides"
    options.
  * Fixed IEEE-1284 device ID generation code.
  * Fixed crash in retrofit printer application.
* Thu Dec 21 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4.4
  * Fixed -n support for setting number of copies
  * Fixed that papplPrinterSetDriverDefaults did not set the
    ``orientation-requested-default`` value
  * Fixed job file preservation logic
* Wed Nov 15 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4.3
  * Added "smi55357-device-uri" and "smi55357-driver" Printer
    Status attributes to Get-Printer-Attributes responses
  * Fixed missing mutex unlock in DNS-SD code
  * Fixed DNS-SD device list crash
* Tue Oct 17 2023 Ich <jengelh@inai.de>
- Update to release 1.4.2
  * Fixed potential crash while listing devices
  * Fixed potential deadlock issue
* Tue Oct 10 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4.1
  * Fixed typos in the names of the papplJobResume and
    papplJobSuspend functions
* Fri Sep 29 2023 Jan Engelhardt <jengelh@inai.de>
- Update to relese 1.4.0
  * Added support for "job-retain-until"
  * Added new PAPPL-Create-Printers operation, and the PAPPL
    mainloop API now auto-adds local printers the first time a
    server is run
  * Added new papplDeviceRemoveScheme and papplDeviceRemoveTypes
    APIs to disable unwanted device types
  * Added support for suspending and resuming jobs at copy boundaries
  * Added support for server configuration files
* Thu Sep  7 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.4
  * Fixed an issue with DNS-SD advertisements when the server name
    was set to "localhost".
  * Fixed an issue with hostname change detection when using
    mDNSResponder.
  * Fixed an issue with authentication cookie comparisons for
    simple password mode.
  * Updated TLS certificate generation to support more types of
    certificates and to use modern OpenSSL/GNU TLS APIs.
* Sat May  6 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.2
  * Fixed PWG ImageBox values in raster page header.
  * Fixed a bug in the "ipp-attribute-fidelity" support.
  * Fixed printing of 1/2/4-bit grayscale PNG images.
  * Fixed a potential buffer overflow in the logging code.
  * Fixed reporting of "xxx-k-octet-supported" attributes.
  * Updated the Wi-Fi configuration page to support hidden networks
    and to reload after 30 seconds.
* Sat Dec 31 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.1
  * Fixed auto-add of USB printers
  * Updated "ipp-attribute-fidelity" support
  * Reduced sleep interval for USB gadget initialization
* Fri Dec  2 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.0
  * Added debug logging for device management.
  * Added support for job hold and release.
  * Added papplLocGetDefaultMediaSizeName function to get the
    default media size for the current country.
  * Added support for localized banners at the top of printer and
    system web pages.
  * Added support for PNG image scaling using embedded resolution
    information.
  * Added timer APIs to manage periodic tasks, APIs to limit the
    max size of JPEG/PNG.
  * Added support for network configuration via callbacks,
  * Updated PAPPL to conform to the new prototype PWG 5100.13
    specification
* Thu Oct 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.3
  * Fixed a bug in the TLS upgrade logic.
  * Fixed a potential memory underflow with USB device IDs.
  * Fixed web interface support for vendor text options.
* Wed Sep 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.2
  * Added debug logging for device management.
  * Fixed a device race condition with job processing.
  * Fixed a potential value overflow when reading SNMP OIDs.
  * Fixed more CUPS 2.2.x compatibility issues.
  * Fixed a 100%% CPU usage bug when cleaning the job history.
  * Fixed the default values of --with-papplstatedir and
  - -with-papplsockdir to use the localstatedir value.
  * Fixed a initialization timing issue with USB gadgets on newer
    Linux kernels.
* Thu May 26 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.1
  * Fixed a bug in the max-clients support code.
  * Fixed corruption in the English localization file.
* Mon May 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.0
  * Added `papplMainloopShutdown` API to trigger a shutdown of the
    system that was started by `papplMainloop`.
  * Fixed mapping of MIME media types to IEEE-1284 Command Set values.
  * Fixed a crash bug when no printers are added.
  * Fixed compatibility issues with libcups3.
- Drop 0001-Define-_FILE_OFFSET_BITS-64-on-linux-Issue-193.patch
  (merged)
* Mon Mar  7 2022 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Define-_FILE_OFFSET_BITS-64-on-linux-Issue-193.patch
* Sun Feb 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.0
  * Support for Wi-Fi configuration, IPP-USB, printer driver
    lookup and auto-add functionality.
* Mon Jun 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.3
  * Fixed using the "auto" driver without an IEEE-1284 device ID
    string.
  * The DNS-SD support functions did not handle when the Avahi
    daemon is not running.
* Sat Dec 12 2020 aloisio@gmx.com
- Update to version 1.0.0
  * papplSystemLoadState would not load printers whose device
    IDs contained the # character.
  * Passing "auto" for the driver name would cause a crash if
    there was no auto-add callback.
  * Added papplPrinterGetPath API to get the path for a
    printer web page.
  * The papplPrinterAddLink and papplSystemAddLink functions
    now accept an "options" argument instead of the "secure"
    boolean in order to allow links to be added to multiple
    places on the web interface in addition to requesting a
    secure (HTTPS) link.
  version 1.0rc1:
  * Added IEEE-1284 device ID to argument list for printer
    driver callbacks.
  * Documentation updated
  * Printers discovered via DNS-SD now report their IEEE-1284
    device ID string.
  * The "auto-add" callback is now part of the system's printer
    driver interface, allowing IPP, web, and command-line
    clients to access it.
  * Now save state after deleting a printer.
  * Now check whether a named printer already exists.
  * Support for "output-bin-default" was missing from the web
    interface.
  * Fixed support for vendor options at the command-line.
  * The main loop now shows an error message if an option is
    provided after "-o" without a space.
  * Fixed test page and identify buttons.
  * Code cleanup.
  * Boolean vendor options are now shown as checkboxes.
  * Made several improvements to the web interface for adding
    printers.
  * papplSystemLoadState no longer crashes when it cannot
    create a printer.
  * Fixed a crash bug in the "autoadd" command provided by
    papplMainloop.
  * Added a printer creation callback to
    papplSystemSetPrinterDrivers that is run after a printer
    is created.
  * Added the "path" value for the DNS-SD printer web page, and
    added a registration for the system web page in multi-queue
    mode.
  * papplDeviceRead now has a 100ms timeout for USB and
    network connections.
  * Implemented back-channel and status updates for the USB
    printer gadget.
  * Finished implementation of test suite for major code
    paths/job processing functionality.
  * Fixed a bug in the log rotation code.
  * Fixed some threading bugs with the various object lists
    managed by the system.
* Thu Nov 12 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0b1
  * Drop 10-second timeout for USB data.
  * Add start of USB ethernet & mass storage gadget support.
  * Make sure an unknown number of pages does not disable
    duplex printing.
  * Pad/crop PWG/Apple raster data rather than erroring out.
* Tue Oct 13 2020 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 0~git378 / 2c2b86eb9e9)
  for build.opensuse.org.
